import * as i0 from '@angular/core';
import { Injectable, Component, ViewEncapsulation, NgModule } from '@angular/core';

class ButterToastNotificationService {
    constructor() {
        this.uniqueToastIncremental = 0;
        this.toastContainer = document.createElement('DIV');
    }
    create(params) {
        /**
         * toastContainer should be created just once
         */
        if (this.uniqueToastIncremental === 0) {
            this.toastContainer.setAttribute('id', 'butter-toast-container');
            this.toastContainer.className = 'butter-toast-container';
            document.body.appendChild(this.toastContainer);
        }
        this.uniqueToastIncremental++; //Used for assigning id to the toast element
        var toast = document.createElement('DIV');
        toast.setAttribute('id', 'butter-toast' + this.uniqueToastIncremental);
        toast.setAttribute('class', 'butter-toast');
        switch (params.type) {
            case 'success':
                toast.className += ' butter-toast-success';
                break;
            case 'warning':
                toast.className += ' butter-toast-warning';
                break;
            case 'danger':
                toast.className += ' butter-toast-danger';
                break;
            case 'info':
                toast.className += ' butter-toast-info';
                break;
            default:
                toast.className += '';
                break;
        }
        if (!!params.title) {
            var title = document.createElement('DIV');
            title.setAttribute('id', 'butter-toast-title' + this.uniqueToastIncremental);
            title.setAttribute('class', 'butter-toast-title');
            title.innerHTML = '<b>' + params.title;
            toast.appendChild(title);
        }
        if (!!params.text) {
            var message = document.createElement('P');
            message.setAttribute('id', 'butter-toast-message' + this.uniqueToastIncremental);
            message.setAttribute('class', 'butter-toast-message');
            message.innerHTML = params.text;
            toast.appendChild(message);
        }
        this.toastContainer.prepend(toast);
        //hide toast after some delayed time
        this.timeoutHide(this.uniqueToastIncremental, params.timeout);
        //hide toast on click event
        toast.addEventListener('click', function (event) {
            toast.setAttribute('class', 'butter-toast-hide');
            setTimeout(() => {
                toast.style.display = "none";
            }, 200);
            setTimeout(() => {
                toast.remove();
            }, 300);
        });
    }
    timeoutHide(id = 0, timeInMs = 2000) {
        setTimeout(() => {
            let toastToHide = document.getElementById('butter-toast' + id);
            toastToHide.setAttribute('class', 'butter-toast-hide');
            setTimeout(() => {
                toastToHide.style.display = "none";
            }, 200);
            setTimeout(() => {
                toastToHide.remove();
            }, 300);
        }, timeInMs);
    }
}
ButterToastNotificationService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
ButterToastNotificationService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return []; } });

class ButterToastNotificationComponent {
    constructor() { }
    ngOnInit() {
    }
}
ButterToastNotificationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ButterToastNotificationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.11", type: ButterToastNotificationComponent, selector: "lib-butterToastNotification", ngImport: i0, template: `
    <div class="butter-toast-container">
      <div class="butter-toast-success">Hi Greedn</div>
    </div>
  `, isInline: true, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-butterToastNotification', encapsulation: ViewEncapsulation.None, template: `
    <div class="butter-toast-container">
      <div class="butter-toast-success">Hi Greedn</div>
    </div>
  `, styles: [] }]
        }], ctorParameters: function () { return []; } });

class ButterToastNotificationModule {
}
ButterToastNotificationModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ButterToastNotificationModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationModule, declarations: [ButterToastNotificationComponent], exports: [ButterToastNotificationComponent] });
ButterToastNotificationModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationModule, imports: [[]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.11", ngImport: i0, type: ButterToastNotificationModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ButterToastNotificationComponent
                    ],
                    imports: [],
                    exports: [
                        ButterToastNotificationComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of butter-toast-notification
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ButterToastNotificationComponent, ButterToastNotificationModule, ButterToastNotificationService };
//# sourceMappingURL=butter-toast-notification.mjs.map
